#
# spec file for package mailman
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define       m_uid 72
%define       m_gid 67
%define       apache2_confd       %{_sysconfdir}/apache2/conf.d
%define       sendmail_libd       %{_libexecdir}/sendmail.d
%define       mailman_confd       %{_sysconfdir}/mailman
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
# Now, the user and group the CGIs will expect to be run under.  This should
# match the user and group the web server is configured to run as.  The scripts
# will error out if they are invoked by any other user.
%define cgiuser wwwrun
%define cgigroup www
Name:           mailman
Version:        2.1.34
Release:        lp152.7.3.1
Summary:        The GNU Mailing List Manager
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Email/Mailinglists
URL:            http://www.gnu.org/software/mailman/mailman.html
Source0:        https://ftp.gnu.org/gnu/mailman/%{name}-%{version}.tgz
Source1:        README.SUSE
Source2:        mailman-2.1-manpages.tgz
Source4:        mailman-generate-sysconfig
Source5:        rcmailman
Source6:        aliases
Source7:        sysconfig.mailman
Source8:        mailman.sgidlist
Source9:        mailman-apache2.conf
Source11:       logrotate.mailman
Source12:       mm-text.png
Source13:       https://ftp.gnu.org/gnu/mailman/%{name}-%{version}.tgz.sig
Source14:       %{name}.keyring
Patch1:         mailman-wrapper.patch
Patch3:         mailman-2.1.14-python.dif
Patch5:         mailman-2.1.14-editarch.patch
Patch6:         mailman-2.1.14-misc-PACKAGES.diff
Patch7:         mailman-2.1.26-list_lists.patch
Patch10:        mailman-2.1.4-dirmode.patch
Patch11:        mailman-2.1.4-notavaliduser.patch
Patch17:        mailman-weak-password.diff
Patch18:        mailman-2.1.5-no_extra_asian.dif
BuildRequires:  krb5
BuildRequires:  pcre-devel
BuildRequires:  postfix
BuildRequires:  pwdutils
BuildRequires:  python-devel
BuildRequires:  python-dnspython
#!BuildIgnore:  sendmail
Requires:       cron
Requires:       logrotate
Requires:       python
Requires:       python-dnspython
Requires:       smtp_daemon
Requires:       w3m
Requires(post): %fillup_prereq
Requires(post): %insserv_prereq
Requires(post): coreutils
Requires(post): gawk
Requires(post): group(%cgigroup)
Requires(post): openssl
Requires(post): user(%cgiuser)
Requires(pre):  shadow

%description
This is the GNU Mailing List manager. Mailman provides an
easy-to-configure means of maintaining mailing lists including Web
administration. Mailman is written in Python.

%prep
%setup -q
%autopatch -p1

cp -av %{SOURCE1} .

%build
# Fix shebangs (in %build, because we want it for all versions of
# pythons)
for scrf in bin/msgfmt.py tests/fblast.py tests/onebounce.py ; do
    sed -i -e '1s@/usr/bin/env python@/usr/bin/python@' "${scrf}"
done
sed -i -e '1s!@PYTHON@!%{_bindir}/python!' contrib/sitemapgen


%configure \
    --prefix=%{_libexecdir}/mailman \
    --exec-prefix=%{_libexecdir}/mailman \
    --localstatedir=%{_localstatedir}/run \
    --libexecdir=%{_libexecdir}/mailman \
    --with-groupname=mailman \
    --with-username=mailman \
    --with-var-prefix=%{_localstatedir}/lib/mailman \
    --without-permcheck \
    --with-cgi-gid=%{cgiuser} \
    --with-mail-gid=%{cgigroup}
make %{?_smp_mflags} OPT="%{optflags} -fpie -pie"

%install
install -d %{buildroot}/{usr/sbin,etc/{mailman,sysconfig,init.d,logrotate.d},%{_fillupdir},bin/conf.d}/
%make_install
# add a hint to the crontab
cat <<EOF > %{buildroot}%{_libexecdir}/mailman/cron/crontab
#
# if you want to make changes to this file, please modify
# /usr/lib/mailman/cron/crontab and restart mailman
#
EOF
# add user mailman in column 6 since we are going to use it as system crontab
awk '/^[0-9,\*]/ { print $1 " " $2 " " $3 " " $4 " " $5 " mailman " $6 " " $7 " " $8 } /^\#/ { print $0 }' \
	%{buildroot}%{_libexecdir}/mailman/cron/crontab.in \
	>> %{buildroot}%{_libexecdir}/mailman/cron/crontab
# write initial wrapper id files:
. %{SOURCE7}
getent group %{cgigroup} \
    | cut -d: -f3 > %{buildroot}/%{mailman_confd}/mailman.cgi-gid
echo %{m_gid} > %{buildroot}/%{mailman_confd}/mailman.mail-gid
# SuSEconfig stuff:
install -m 644 %{SOURCE7} %{buildroot}%{_fillupdir}/
install -m 755 %{SOURCE4} %{buildroot}%{_libexecdir}/mailman/bin/
install -m 644 %{SOURCE8} %{buildroot}%{_libexecdir}/mailman/sgidlist
# start script:
ln -sf ../..%{_initddir}/mailman %{buildroot}%{_sbindir}/rcmailman
install -m 755 %{SOURCE5} %{buildroot}%{_initddir}/mailman
# make sure there is a valid  group writable aliases.db
# if the aliases.db would be generated later on, list creation
# through the web interface would not work!
install -m 664 %{SOURCE6} %{buildroot}%{_localstatedir}/lib/mailman/data/aliases
# created in %%post and marked as %%ghost in the file section, so simply fake it:
%{_bindir}/touch %{buildroot}%{_localstatedir}/lib/mailman/data/aliases.db
# apache stuff:
mkdir -p %{buildroot}/%{apache2_confd}
cp -av %{SOURCE9} %{buildroot}/%{apache2_confd}/mailman.conf
# link to enhance interoperability with Sendmail
mkdir -p %{buildroot}/%{sendmail_libd}/bin
ln -sf %{_libexecdir}/mailman/mail/mailman %{buildroot}/%{sendmail_libd}/bin/mailman
install -d %{buildroot}%{_mandir}/man8/
tar xz -C %{buildroot}%{_mandir}/man8/ -f %{SOURCE2}
install -m 644 %{SOURCE11} %{buildroot}%{_sysconfdir}/logrotate.d/mailman
# Better solution for bsc#1154328 (and bnc#697638)
install -m 0664 -D /dev/null %{buildroot}/var/lib/%{name}/logs/error

%pre
getent group mailman >/dev/null || %{_sbindir}/groupadd -g %{m_gid} -o -r mailman
getent passwd mailman >/dev/null || %{_sbindir}/useradd -r -o -g mailman -u %{m_uid} -s /bin/bash -c "GNU mailing list manager" -d %{_localstatedir}/lib/mailman mailman
exit 0

%post
%{fillup_and_insserv mailman}
# handle very old installations
test -d %{_localstatedir}/spool/mailman && {
    echo -n "Moving %{_localstatedir}/spool/mailman -> %{_localstatedir}/lib/mailman... "
    (cd %{_localstatedir}/lib/mailman && cp -a %{_localstatedir}/spool/mailman/* .)  && rm -rf %{_localstatedir}/spool/mailman
    echo "Done."
}
echo "All done."
# use Mailman facilities for updating old data
%{_libexecdir}/mailman/bin/update
if test -z "$YAST_IS_RUNNING" ; then
    echo "Please remember to run '%{_libexecdir}/mailman/bin/mailman-generate-sysconfig' to configure mailman"
fi
# re-create the list aliases
%{_libexecdir}/mailman/bin/genaliases > /dev/null
# update the alias db file and make it group-writeable (important for being able to create mailing lists thru the web interface)
if [ -x %{_sbindir}/postalias -a -r %{_localstatedir}/lib/mailman/data/aliases ]; then
    %{_sbindir}/postalias %{_localstatedir}/lib/mailman/data/aliases || :
    chmod g+w %{_localstatedir}/lib/mailman/data/aliases.db
fi
exit 0

%verifyscript
%verify_permissions -f %{_libexecdir}/mailman/sgidlist

%preun
%stop_on_removal mailman

%postun
%restart_on_update mailman
%insserv_cleanup

%files
%license gnu-COPYING-GPL
%doc ACKNOWLEDGMENTS BUGS FAQ INSTALL NEWS TODO UPGRADING contrib doc/mailman-admin
%doc README README.*
%{_mandir}/man8/*.8%{?ext_man}
%dir %{mailman_confd}
%config(noreplace) %{_sysconfdir}/logrotate.d/mailman
%config(noreplace) %{mailman_confd}/mailman.*-gid
%dir %attr(-, root, mailman) %{_libexecdir}/mailman/
%{_libexecdir}/mailman/sgidlist
%attr(-, root, mailman) %{_libexecdir}/mailman/[^Mmc]*
%attr(-, root, mailman) %{_libexecdir}/mailman/cron
%dir %attr(-, root, mailman) %{_libexecdir}/mailman/cgi-bin
%verify(not mode) %attr(2755, root, mailman) %{_libexecdir}/mailman/cgi-bin/*
%dir %attr(2755, root, mailman) %{_libexecdir}/mailman/Mailman/
%attr(-, root, mailman) %{_libexecdir}/mailman/Mailman/[^m]*
%attr(-, root, mailman) %{_libexecdir}/mailman/messages
%dir %attr(-, root, mailman) %{_libexecdir}/mailman/mail
%verify(not mode) %attr(2755, root, mailman) %{_libexecdir}/mailman/mail/mailman
%config(noreplace) %attr(-, root, mailman) %{_libexecdir}/mailman/Mailman/m*
%dir %attr(2755, mailman, mailman) %{_localstatedir}/lib/mailman/
%attr(-, root, mailman) %{_localstatedir}/lib/mailman/[^d]*
%dir %attr(750, mailman, www) %{_localstatedir}/lib/mailman/archives
%dir %attr(750, mailman, www) %{_localstatedir}/lib/mailman/archives/private
%dir %attr(2775, root, mailman) %{_localstatedir}/lib/mailman/data/
%config(noreplace) %attr(-, root, mailman) %{_localstatedir}/lib/mailman/data/[^a]*
%config(noreplace) %attr(-, mailman, mailman) %{_localstatedir}/lib/mailman/data/aliases
%ghost %attr(0664, wwwrun, mailman) %{_localstatedir}/lib/mailman/logs/error
%ghost %attr(0664, mailman, mailman) %{_localstatedir}/lib/mailman/data/aliases.db
%{_fillupdir}/*
%{_sbindir}/*
%{_initddir}/*
%dir %{_sysconfdir}/apache2
%dir %{apache2_confd}
%config (noreplace) %{apache2_confd}/mailman.conf
%dir %{sendmail_libd}
%dir %{sendmail_libd}/bin
%{sendmail_libd}/bin/mailman

%changelog
* Thu Oct 15 2020 Matej Cepl <mcepl@suse.com>
- Update to 2.1.34:
  - The fix for lp#1859104 can result in ValueError being thrown
    on attempts to subscribe to a list. This is fixed and
    extended to apply REFUSE_SECOND_PENDING to unsubscription as
    well. (lp#1878458)
  - DMARC mitigation no longer misses if the domain name returned
    by DNS contains upper case. (lp#1881035)
  - A new WARN_MEMBER_OF_SUBSCRIBE setting can be set to No to
    prevent mailbombing of a member of a list with private
    rosters by repeated subscribe attempts. (lp#1883017)
  - Very long filenames for scrubbed attachments are now
    truncated. (lp#1884456)
  - A content injection vulnerability via the private login page
    has been fixed. CVE-2020-15011  (lp#1877379, bsc#1173369)
  - A content injection vulnerability via the options login page
    has been discovered and reported by Vishal Singh.
    CVE-2020-12108 (lp#1873722, bsc#1171363)
  - Bounce recognition for a non-compliant Yahoo format is added.
  - Archiving workaround for non-ascii in string.lowercase in
    some Python packages is added.
  - Thanks to Jim Popovitch, there is now
    a dmarc_moderation_addresses list setting that can be used to
    apply dmarc_moderation_action to mail From: addresses listed
    or matching listed regexps. This can be used to modify mail
    to addresses that don't accept external mail From:
    themselves.
  - There is a new MAX_LISTNAME_LENGTH setting. The fix for
    lp#1780874 obtains a list of the names of all the all the
    lists in the installation in order to determine the maximum
    length of a legitimate list name. It does this on every web
    access and on sites with a very large number of lists, this
    can have performance implications. See the description in
    Defaults.py for more information.
  - Thanks to Ralf Jung there is now the ability to add text
    based captchas (aka textchas) to the listinfo subscribe form.
    See the documentation for the new CAPTCHA setting in
    Defaults.py for how to enable this. Also note that if you
    have custom listinfo.html templates, you will have to add
    a <mm-captcha-ui> tag to those templates to make this work.
    This feature can be used in combination with or instead of
    the Google reCAPTCHA feature added in 2.1.26.
  - Thanks to Ralf Hildebrandt the web admin Membership
    Management section now has a feature to sync the list's
    membership with a list of email addresses as with the
    bin/sync_members command.
  - There is a new drop_cc list attribute set from
    DEFAULT_DROP_CC. This controls the dropping of addresses from
    the Cc: header in delivered messages by the duplicate
    avoidance process. (lp#1845751)
  - There is a new REFUSE_SECOND_PENDING mm_cfg.py setting that
    will cause a second request to subscribe to a list when there
    is already a pending confirmation for that user. This can be
    set to Yes to prevent mailbombing of a third party by
    repeatedly posting the subscribe form. (lp#1859104)
  - Fixed the confirm CGI to catch a rare TypeError on
    simultaneous confirmations of the same token. (lp#1785854)
  - Scrubbed application/octet-stream MIME parts will now be
    given a .bin extension instead of .obj. CVE-2020-12137
    (lp#1886117)
  - Added bounce recognition for a non-compliant opensmtpd DSN
    with Action: error. (lp#1805137)
  - Corrected and augmented some security log messages.
    (lp#1810098)
  - Implemented use of QRUNNER_SLEEP_TIME for bin/qrunner
  - -runner=All. (lp#1818205)
  - Leading/trailing spaces in provided email addresses for login
    to private archives and the user options page are now
    ignored. (lp#1818872)
  - Fixed the spelling of the --no-restart option for mailmanctl.
  - Fixed an issue where certain combinations of charset and
    invalid characters in a list's description could produce
    a List-ID header without angle brackets. (lp#1831321)
  - With the Postfix MTA and virtual domains, mappings for the
    site list -bounces and -request addresses in each virtual
    domain are now added to data/virtual-mailman (-owner was done
    in 2.1.24). (lp#1831777)
  - The paths.py module now extends sys.path with the result of
    site.getsitepackages() if available. (lp#1838866)
  - A bug causing a UnicodeDecodeError in preparing to send the
    confirmation request message to a new subscriber has been
    fixed. (lp#1851442)
  - The SimpleMatch heuristic bounce recognizer has been improved
    to not return most invalid email addresses. (lp#1859011)
- Remove patch included upstream:
  - CVE-2020-12108_injection_options.patch
- Patches reapplied on the new tarball:
  - mailman-2.1.14-editarch.patch
  - mailman-2.1.14-python.dif
  - mailman-2.1.4-notavaliduser.patch
  - mailman-2.1.5-no_extra_asian.dif
  - mailman-weak-password.diff
* Tue May 12 2020 Matej Cepl <mcepl@suse.com>
- Add CVE-2020-12108_injection_options.patch fixing bsc#1171363
  (CVE-2020-12108)
- Make two remaining patches -p1 as well:
  - mailman-2.1.26-list_lists.patch
  - mailman-wrapper.patch
* Mon May 11 2020 Matej Cepl <mcepl@suse.com>
- Don't default to invalid hosts for DEFAULT_EMAIL_HOST
  (bsc#682920), adjust mailman-2.1.14-python.dif.
- Reapply and adjust remaining patches:
  - mailman-2.1.14-editarch.patch
  - mailman-2.1.4-dirmode.patch
  - mailman-2.1.4-notavaliduser.patch
  - mailman-2.1.5-no_extra_asian.dif
  - mailman-weak-password.diff
* Tue Apr 28 2020 Matej Cepl <mcepl@suse.com>
- Fix rights and ownership on /var/lib/mailman/archives (bsc#1167068)
* Fri Jan 24 2020 Johannes Segitz <jsegitz@suse.de>
- Don't use explicit chown and chmod in %%post, but rather use
  %%attr in files. Avoid bsc#1154328 (CVE-2019-3693)
* Mon Feb 25 2019 Matej Cepl <mcepl@suse.com>
- boo#1095112: add /etc/mailman/mailman.cgi-gid and fix user
  rights.
* Fri Aug  3 2018 liedke@rz.uni-mannheim.de
- update to 2.1.29:
  * Fixed the listinfo and admin overview pages that were broken
* Tue Jul 24 2018 liedke@rz.uni-mannheim.de
- update to 2.1.28:
  * A content spoofing vulnerability with invalid list name messages in
    the web UI has been fixed.  CVE-2018-13796 bsc#1101288
  * It is now possible to edit HTML and text templates via the web admin
    UI in a supported language other than the list's preferred_language.
  * The Japanese translation has been updated
  * The German translation has been updated
  * The Esperanto translation has been updated
  * The BLOCK_SPAMHAUS_LISTED_DBL_SUBSCRIBE feature added in 2.1.27 was
    not working.  This is fixed.
  * Escaping of HTML entities for the web UI is now done more selectively.
* Thu Jun 28 2018 liedke@rz.uni-mannheim.de
- update to 2.1.27
  * Existing protections against malicious listowners injecting evil
    scripts into listinfo pages have had a few more checks added.
    JVN#00846677/JPCERT#97432283/CVE-2018-0618 (boo#1099510)
  * A few more error messages have had their values HTML escaped.
    JVN#00846677/JPCERT#97432283/CVE-2018-0618 (boo#1099510)
  * The hash generated when SUBSCRIBE_FORM_SECRET is set could have been
    the same as one generated at the same time for a different list and
    IP address.  While this is not thought to be exploitable in any way,
    the generation has been changed to avoid this.
  * An option has been added to bin/add_members to issue invitations
    instead of immediately adding members.
  * A new BLOCK_SPAMHAUS_LISTED_IP_SUBSCRIBE setting has been added to
    enable blocking web subscribes from IPv4 addresses listed in Spamhaus
    SBL, CSS or XBL.  It will work with IPv6 addresses if Python's
    py2-ipaddress module is installed.  The module can be installed via pip
    if not included in your Python.
  * Mailman has a new 'security' log and logs
    authentication failures to the various web CGI functions.  The logged
    data include the remote IP and can be used to automate blocking of IPs
    with something like fail2ban.  Since Mailman 2.1.14, these have returned
    an http 401 status and the information should be logged by the web
    server, but this new log makes that more convenient.  Also, the
    'mischief' log entries for 'hostile listname' noe include the remote IP
    if available.
  * admin notices of (un)subscribes now may give
    the source of the action.  This consists of a %%(whence)s replacement
    that has been added to the admin(un)subscribeack.txt templates.  Thanks
    to Yasuhito FUTATSUKI for updating the non-English templates and help
    with internationalizing the reasons.
  * there is a new
    BLOCK_SPAMHAUS_LISTED_DBL_SUBSCRIBE setting to enable blocking web
    subscribes for addresses in domains listed in the Spamhaus DBL.
  * i18n & Bugfixes
  * for further details see NEWS
* Mon Mar 19 2018 tchvatal@suse.com
- Fix install prefix for some of the files
- Install license file
* Fri Mar 16 2018 tchvatal@suse.com
- Sort out with spec-cleaner
- Use direct paths in post scriptlets and properly state their deps
- Do not attempt user creation during build, fails anyway
- Use proper user creation code in scriptlets
* Thu Mar 15 2018 liedke@rz.uni-mannheim.de
- update to 2.1.26
  * An XSS vulnerability in the user options CGI could allow a crafted
    URL to execute arbitrary javascript in a user's browser.  A
    related issue could expose information on a user's options page
    without requiring login. (CVE-2018-5950) bsc#1077358
  * Google reCAPTCHA v2
  * New bin/mailman-config command to display various information
    about this Mailman version and how it was configured.
  * bug fixes, i18n updates
  * for further details see NEWS
- updato to 2.1.25
  * The admindb held subscriptions listing now includes the date of the
    most recent request from the address.
  * bug fixes, i18n updates
  * for further details see NEWS
- update to 2.1.24
  * bug fixes, i18n updates
  * for further details see NEWS
- Rename and refresh patch:
  * mailman-2.1.2-list_lists.patch to mailman-2.1.26-list_lists.patch
* Mon Nov 27 2017 dmueller@suse.com
- remove distributable flag (which is always true):
  drops SuSEconfig.mailman-SuSE, mailman-SuSE.patch, mailman-SuSE2.patch
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Thu Jun 29 2017 dimstar@opensuse.org
- Fix pre script for usage with more recent postfix versions.
* Mon Mar 20 2017 kukuk@suse.de
- Require system user wwwrun
* Mon Feb 20 2017 kukuk@suse.de
- Require fillup and insserv if we call them
* Mon Aug 29 2016 hsk17@mail.de
- update to 2.1.23
  * CSRF protection in user options page (CVE-2016-6893)
  * header_filter_rules matching: headers and patterns are all
    decoded to unicode
  * another possible REMOVE_DKIM_HEADERS setting
  * SMTPDirect.py can now do SASL authentication and STARTTLS
  * bug fixes, i18n updates
  * for further details see NEWS
* Mon Apr 18 2016 hsk@imb-jena.de
- update to 2.1.22
  * bug fixes, i18n updates; for details see NEWS
* Tue Mar 29 2016 hsk@imb-jena.de
- updated mailman-apache2.conf to support "require" syntax of recent
  apache httpd
* Mon Feb 29 2016 hsk@imb-jena.de
- update to 2.1.21
  * new dmarc_none_moderation_action list setting
  * new feature to automatically turn on moderation for single list
    members (spam prevention)
  * new mm_cfg.py setting GLOBAL_BAN_LIST
  * translation updates and bug fixes
  * for more details see NEWS and Mailman/Defaults.py
- mailman-2.1.4-dirmode.patch: adjusted to 2.1.21
* Wed Feb  3 2016 mpluskal@suse.com
- Use url for source
- Add gpg signature
* Tue Mar 31 2015 hsk@imb-jena.de
- update to 2.1.20
  * fix for CVE-2015-2775 (path traversal vulnerability)
  * new Address Change sub-section in the web admin Membership
    Management section
  * translation updates and bug fixes
* Mon Mar  2 2015 hsk@imb-jena.de
- update to 2.1.19
  * backports from 2.2 development branch
  - new list attribute 'subscribe_auto_approval'
  - added 'automate' option to bin/newlist
  - processing of Topics regular expressions has changed
  - added real name display to the web roster, controlled by new
    ROSTER_DISPLAY_REALNAME setting
  - bug fixes
  * new list attribute dmarc_wrapped_message_text and
    DEFAULT_DMARC_WRAPPED_MESSAGE_TEXT setting
  * new list attribute equivalent_domains and DEFAULT_EQUIVALENT_DOMAINS
    setting
  * new WEB_HEAD_ADD setting
  * new DEFAULT_SUBSCRIBE_OR_INVITE setting
  * new list attribute bounce_notify_owner_on_bounce_increment and
    DEFAULT_BOUNCE_NOTIFY_OWNER_ON_BOUNCE_INCREMENT setting
  * log files, request.pck files and heldmsg-* files are no longer created
    world readable
  * i18n updates
  * bug fixes
* Fri Oct 17 2014 hsk@imb-jena.de
- update to 2.1.18
  * mailman now requires dnspython
  * new dmarc_moderation_action feature and corresponging list and default
    settings
  * bug fixes
* Fri Feb 14 2014 jmatejek@suse.com
- rename README.SuSE
- update to 2.1.17
  * option to strip/keep non-standard headers in anonymous lists
  * option to make membership checks on mail-news gateway
  * UI improvements for admin interface
  * digest_size_threshold = 0 now means that *no* digest is sent
    based on size
  * option to CSRF-protect subscription form
  * admins can add members with mail delivery disabled
  * configurable name of master lock
  * updated translations
- updated list_lists patch because upstream list_lists now has
  an argument -p / --public-archive that does the same as SUSE-specific
  argument -u / --public-archives. Both spellings are supported
  and are synonymous.
* Tue Feb 11 2014 dmueller@suse.com
- do not abort post script if postalias fails
* Wed Oct 24 2012 jmatejek@suse.com
- update to 2.1.15
  * fixes CVE-2011-0707 - patch dropped
  * better CSRF protection
  * better e-mail address validation
  * password reminder button
  * new config options
  * updated translations
- dropped mailman-python24 patch as we no longer care
  about python2.4
- replaced %%run_permissions in spec
* Tue Oct  2 2012 jmatejek@suse.com
- removed SuSEconfig dependency
  * SuSEconfig.mailman is moved to a new location, and works
    pretty much the same way as before. which may or may not
    be a good thing, perhaps this functionality should be
    removed completely
* Fri Mar  2 2012 opensuse@cboltz.de
- add "su mailman mailman" to logrotate config (bnc#750259)
* Wed Apr 20 2011 jmatejek@novell.com
- fixed bug where it is impossible to edit archives (updated
  patch 2.1.14-editarch.patch)
* Wed Feb 23 2011 matejcik@suse.cz
- fixed a XSS vulnerability in confirm.py (CVE-2011-0707, bnc#671745)
* Mon Nov 15 2010 dmueller@suse.de
- update to 2.1.14:
  - Two potential XSS vulnerabilities have been identified and fixed.
  - Various i18n updates
  - A new feature for controlling the addition/replacement of the Sender:
  header in outgoing mail has been implemented.  This allows a list owner
  to set include_sender_header on the list's General Options page in the
  admin GUI.  The default for this setting is Yes which preserves the prior
  behavior of removing any pre-existing Sender: and setting it to the
  list's -bounces address.  Setting this to No stops Mailman from adding or
  modifying the Sender: at all.
  - long list of bug fixes and enhancements, see included NEWS for details
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Sun Nov 30 2008 rommel@suse.de
- the previous 'fix' of removing Mailman's own version of email was a bit crude
  and broke Mailman in several places (bug #448530)
  I replaced it with the upstream fix to 'configure' by Barry Warshaw
  (see http://bazaar.launchpad.net/~barry/mailman/py26/changes)
* Wed Nov 12 2008 rommel@suse.de
- added fix to work around md5/sha deprecation warning when hashlib is available
  (mailman-python-26-deprecation-md5-sha.diff)
- removed group writable bit from /usr/lib/mailman/Mailman/
- removing Mailman's own version of email when building against >= Python 2.6
* Tue Aug 26 2008 rommel@suse.de
- version update to 2.1.11 (security fixes and small, but compatible enhancements)
- removed outdated (>4y) extra FAQ
- updated README.SuSE
- reworked (internally used) category patch + added referenced mm-text.png
* Thu Mar 29 2007 ro@suse.de
- added pwdutils to buildreq
* Fri Oct 20 2006 lmuelle@suse.de
- ensure not to quote None if set in /etc/sysconfig/mailman:MAILMAN_MTA
* Thu Oct 12 2006 rommel@suse.de
- upgrade to Mailman 2.1.9 which
  + fixes some security issues (CVE-2006-2941, CVE-2006-3636, CVE-2006-2191)
  + adds support for languages "Arabic" and "Vietnamese"
  + makes the queue handling more robust
  + makes the handling of header/footers more robust
* Fri Jun 23 2006 poeml@suse.de
- add more info about adding "MAILMAN" to the apache server flags to
  README.SuSE and /etc/apache2/conf.d/mailman.conf
* Fri Jun 16 2006 rommel@suse.de
- update to version 2.1.8 which btw obsoletes these patches:
  mailman-2.1.4-mktime_overflowerror.patch
  mailman-2.1.4-cleanarch.patch
  mailman-2.1.7-patch-20060114.txt
- fixed an error in the comments of sysconfig.mailman
  (MAILMAN_SMTPPORT is relevant for MAILMAN_SMTPHOST, not MAILMAN_DEFAULT_EMAIL_HOST)
* Thu Mar 16 2006 rommel@suse.de
- applied a bugfix collection for Mailman 2.1.7 from
  http://sourceforge.net/tracker/index.php?func=detail&aid=1405790&group_id=103&atid=300103
- reworked the handling of the alias db file (using the %%ghost tag)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 rommel@suse.de
- fixed cleanarch [bug #144675]
- reworked mailman-2.1.4-mktime_overflowerror.patch [bug #143390]
- removed python-xml from Requires: (was introduced by obsolete patch)
* Mon Jan  9 2006 rommel@suse.de
- update to version 2.1.7 (rediff of mailman-wrapper.patch,
  mailman-python24.patch, mailman-2.1.5-no_extra_asian.dif)
* Thu Aug 11 2005 lnussel@suse.de
- fix permission handling (#66315)
* Tue Jul 12 2005 rommel@suse.de
- fixed check_perms [bug #76172]
- added support for logrotate [bug #94379]
* Sat Jul  2 2005 dmueller@suse.de
- update to Mailman 2.1.6, rediff and remove patches
  which are already included upstream
* Wed Jun 15 2005 meissner@suse.de
- use RPM_OPT_FLAGS and PIE support for C binaries (CGI bins mostly)
* Wed Feb 16 2005 rommel@suse.de
- added mailman-2.1.5-dirtraversal.patch [bug #50563, CAN-2005-0202]
* Mon Feb 14 2005 ro@suse.de
- should not need explicit importing of japanese and korean
  any more with current python, remove it
* Thu Feb 10 2005 ro@suse.de
- remove python-korean and python-japanese (pkgs dropped)
* Mon Feb  7 2005 rommel@suse.de
- added python-xml to requires [bug #50100]
- fixed permissions on default error log file [bug #48208]
- fixed possible data loss situation while updating [bug #48209]
* Sat Jan 15 2005 schwab@suse.de
- Use <owner>:<group> in permissions file.
* Fri Jan 14 2005 rommel@suse.de
- added hints in README.SuSE on how to activate the web interface [bug #43292]
- added documentation tree from admin/www and debian's man pages [bug #37394]
- added sysconfig support for SMTPPORT [bug #49551]
* Wed Jan 12 2005 rommel@suse.de
- added mailman-weak-password.diff [bug #49468, CAN-2004-1144]
- added mailman-CAN-2004-1177.patch [bug #49468, CAN-2004-1177]
- added mailman-2.1.4-avoid-headerfolding-python21.diff [bug #45355]
- reworked undistributable mailman patch (archive fallback path)
* Wed Dec 15 2004 ro@suse.de
- another permissions fix
* Fri Dec  3 2004 ro@suse.de
- package according to permissions
* Wed Nov 10 2004 rommel@suse.de
- reworked start script (bug #42652)
* Thu Sep 16 2004 mmj@suse.de
- Include latest and greatest FAQ [#38461]
* Thu Sep  2 2004 mmj@suse.de
- Remove mail to root telling him to RTFM [#44365]
* Mon Aug 30 2004 ro@suse.de
- remove apache1 traces
* Sat Aug  7 2004 rommel@suse.de
- update to version 2.1.5
- fix of start script (bug #42652)
* Mon Jun 21 2004 ro@suse.de
- fix filelist
* Sun Jun 20 2004 rommel@suse.de
- relocating mm_cfg.py doesn't work, switched back to old behauviour (won't fix
  bug #41344)
- re-generating aliases in %%post section (important for update)
* Thu Jun  3 2004 rommel@suse.de
- fixed bug introduced by relocation of config files (bug #41344)
- updating mailing list aliases on install or update (important for
  autogenerated aliases)
- updated README.SuSE to reflect recent changes
* Fri May  7 2004 rommel@suse.de
- new configuration directory /etc/mailman
- moved mm_cfg.py to /etc/mailman (bug #38868)
- precompiled stuff in /usr/lib/mailman/bin (bug #38868)
- added support for https per default (bug #38460)
- added patch agains overflow in ArchRunner
  (Request ID 938301 on http://sourceforge.net/projects/mailman/)
- added glue patch for Scrubber
  (Request ID 891491 on http://sourceforge.net/projects/mailman/)
* Thu Mar 25 2004 rommel@suse.de
- added python-japanese and python-korean to Prereq (bug #36214)
* Wed Mar  3 2004 rommel@suse.de
- fixed traceback in options page (bug #35267)
- fixed german messages file (bug #35109)
* Wed Feb 18 2004 rommel@suse.de
- fixed some bugs concerning the wrapper gid files
  (/etc/mailman.*-gid) (see bugs #34614 #34382)
* Thu Feb 12 2004 rommel@suse.de
- removing stale lockfiles on start (bug #34016)
- fixed a typo in SuSEconfig.mailman (bug #34015)
- fixed Defaults.py to work around upgrade problem (bug #33793)
- fixed permissions in /usr/lib/mailman (bug #33792)
- added support for virtual hosts through SuSEconfig.mailman (feature request)
- added a hint to crontab where the master crontab is (feature request)
- added a patch for more options to list_lists (feature request)
- fixed a permission problem caused by editarch
* Thu Jan 15 2004 rommel@suse.de
- upgrade to version 2.1.4 (includes fix for latest XSS vulnerability)
- added link for better Sendmail interoperability
- added "--with-python-lib" to configure to work around hard coded /usr/lib
  manifestations
* Tue Dec 16 2003 rommel@suse.de
- added fix against XSS vulnerability (bug #32187)
- avoiding copies of mailman icons in /srv/www/icon;
  using the IMAGE_LOGOS config switch and an apache/apache2 config instead
  (bug #32496)
- added missing contrib directory to /usr/share/doc/packages/mailman/
- changed ownership of /var/lib/mailman to 2755 so pam ssh doesn't complain
* Tue Nov 25 2003 rommel@suse.de
- added missing calls "stop" on uninstall and "try-restart" on update (bug #29047)
- added w3m as requirement (bug #32706)
- not marking mm_cfg.pyc as config (bug #32851)
- added apache2 config (bug #33187)
* Sat Nov  1 2003 adrian@suse.de
- update to version 2.1.3
* Thu Aug 21 2003 mmj@suse.de
- The fix below from mcihar@suse.cz was a little to rough, since
  mailman broke without it's own copy of email. So include email
  in the installation, but keep korean and japanese disabled.
* Thu Aug 14 2003 rommel@suse.de
- added activation metadata in sysconfig templates
* Mon Aug 11 2003 mcihar@suse.cz
- don't include in mailman package python modules we also ship (korean,
  japanese, email)
- notify user about running 'SuSEconfig --module mailman' if not in YaST
* Mon Aug 11 2003 rommel@suse.de
- bug-fix update to version 2.1.2
- removed now-obsolete mailman-destdir.patch
- linkage of /etc/aliases.d/mailman to /var/lib/mailman/data/aliases
  has been dropped (unmaintainable)
- fixed mailmanctl to not freeze YaST2 [Bug #26990]
- fixed mail gid auto detection in SuSEconfig.mailman [Bug #27369]
- fixed Defaults.py to not reference build host [Bug #26988]
* Tue Aug  5 2003 ro@suse.de
- don't leave buildroot traces in installed files
* Fri Jun 13 2003 kukuk@suse.de
- Fix filelist
* Mon May 12 2003 rommel@suse.de
- added DISTRIBUTABLE to be able to build the version used interally
* Mon Mar 17 2003 kukuk@suse.de
- Don't enable mailman per default, does not work without correct
  configuration
* Mon Mar 10 2003 rommel@suse.de
- test for presence of /usr/sbin/postalias (reported by Eberhard Moenkeberg)
- added RPM Summary [Bug #24810]
- added Description to rcmailman (shows in runlevel editor)
* Thu Mar  6 2003 kukuk@suse.de
- Add openssl PreRequires [Bug #24785]
* Mon Feb 10 2003 rommel@suse.de
- update to version 2.1.1 which obsoletes both mailman-xss.patch and
  mailman-syncmember.patch and fixes the rmlist bug
- added the config attribute to the alias file generated by mailman
  so it does not get lost on package removal
- added MAILMAN_LINK_ALIASES variable to the sysconfig stuff so one
  can create links in /etc/aliases.d that point to
  /var/lib/mailman/data/aliases* independent on the value of MAILMAN_MTA
* Sat Feb  1 2003 rommel@suse.de
- fixed the start script to not freeze the runlevel editor on service start
- added metadata to sysconfig.apache-mailman
* Thu Jan 30 2003 rommel@suse.de
- added missing metadata to sysconfig file
- added official patch against cross-site-scripting (XSS) vulnerability
* Wed Jan 29 2003 rommel@suse.de
- update to version 2.1
- new start script
- new README.SuSE
- added SuSEconfig script that generates the wrapper gid files
  (/etc/mailman.*-gid) and provides an easy way to generate mm_cfg.py
  (Mailman's site configuration file)
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Aug 30 2002 vinil@suse.cz
- enhanced PreRequires
- fixed default hostname in SuSEconfig (bug #17696)
- defaults set for Postfix MTA (Sendmail made optional)
* Mon Aug 12 2002 vinil@suse.de
- new version: 2.0.13
* Fri Aug  2 2002 ro@suse.de
- adapted server root
* Thu Jul 11 2002 vinil@suse.cz
- new version: 2.0.12
- own user and group 'mailman'
- use /etc/aliases.d/mailman instead of /etc/aliases
- paragraph about creating ML added into README.SuSE
* Mon Jun  3 2002 ro@suse.de
- fix build on lib64
- added openssl to neededforbuild
* Thu Jan 31 2002 vinil@suse.cz
- README.SuSE typo fixed
* Thu Jan 24 2002 vinil@suse.cz
- add rcscript, that moves crontab entry in /etc/cron.d/ and out
* Wed Jan 16 2002 ro@suse.de
- adapted for /etc/sysconfig/apache
* Wed Jan 16 2002 vinil@suse.cz
- installation is able to handle old /var/spool/mailman, now
- /var/lib/mailman/Mailman/mm_cfg.py* is %%config(noreplace)
* Tue Dec 11 2001 vinil@suse.cz
- update to 2.0.8
- web frontend prepared for apache
- patch for configuratable cgi-gid and mail-gid
- taking care about /etc/aliases now
* Sun Aug 19 2001 iboernig@suse.de
- update to new stable version 2.0.6
* Sun Aug 19 2001 iboernig@suse.de
- fixed bug in specfile (Bug #9519) Apache GID is now nogroup again.
* Wed Apr 25 2001 iboernig@suse.de
- changed mailgid to "daemon". It should work now with sendmail.
  Postfix users have to change default_privs
* Fri Mar 16 2001 iboernig@suse.de
- updated to version 2.0.3, includes minor security fix
* Fri Jan  5 2001 iboernig@suse.de
- bugfix: move crontab entry to /etc/cron.d/mailman
- notify user in %%post-section
- created README.SuSE
* Thu Dec 28 2000 choeger@suse.de
- bugfix: --prefix=$RPM_BUILD_ROOT does NOT work, because then
    /var/tmp/mailman-* would be compiled into some .c files
    changed Makefiles to allow DESTDIR=/path
- create crontab entries in postinstall
- use gid of nogroup also for mail-wrapper
* Thu Nov 30 2000 iboernig@suse.de
- changed default user.group to mdom.mdom
* Wed Nov 29 2000 iboernig@suse.de
- initial version
